==> jc-1.4.0.tar.gz: jas/FieldCP.h <==
// public class jas.FieldCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class d551d5211cd0b181 jas_FieldCP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_FieldCP_H_
#define _JC_jas_FieldCP_H_

// Forward structure declarations
struct _jc_jas_ClassCP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_NameTypeCP$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_FieldCP$sub_refs	_jc_jas_FieldCP$sub_refs;
typedef struct _jc_jas_FieldCP$sub_nonrefs	_jc_jas_FieldCP$sub_nonrefs;
typedef struct _jc_jas_FieldCP$refs	_jc_jas_FieldCP$refs;
typedef struct _jc_jas_FieldCP$nonrefs	_jc_jas_FieldCP$nonrefs;
typedef struct _jc_jas_FieldCP$object	_jc_jas_FieldCP$object;

typedef const struct _jc_jas_FieldCP$vmethods	_jc_jas_FieldCP$vmethods;
typedef const struct _jc_jas_FieldCP$vtable	_jc_jas_FieldCP$vtable;
typedef const struct _jc_jas_FieldCP$vtype	_jc_jas_FieldCP$vtype;

// Constructors
extern void _jc_jas_FieldCP$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern void _jc_jas_FieldCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_FieldCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_FieldCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_FieldCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_FieldCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_FieldCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_FieldCP$vmethods	jas_FieldCP;
};

// Vtype
struct _jc_jas_FieldCP$vtype {
	_jc_type			type;
	_jc_jas_FieldCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_FieldCP$sub_refs {
	struct _jc_jas_ClassCP$object	*clazz;
	struct _jc_jas_NameTypeCP$object	*nt;
};

// Reference instance fields (object)
struct _jc_jas_FieldCP$refs {
    _jc_jas_FieldCP$sub_refs	jas_FieldCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_FieldCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_FieldCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_FieldCP$sub_nonrefs	jas_FieldCP;
};

// Object instance structure
struct _jc_jas_FieldCP$object {
	_jc_jas_FieldCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_FieldCP$vtype	*vtype;
	_jc_jas_FieldCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_FieldCP$vtype _jc_jas_FieldCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_FieldCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_FieldCP$class_object;

#endif	/* _JC_jas_FieldCP_H_ */

==> jc-1.4.6.tar.gz: jas/FieldCP.h <==
// public class jas.FieldCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class d551d5211cd0b181 jas_FieldCP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_FieldCP_H_
#define _JC_jas_FieldCP_H_

// Forward structure declarations
struct _jc_jas_ClassCP$object;
struct _jc_jas_ClassEnv$object;
struct _jc_jas_NameTypeCP$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_jas_FieldCP$sub_refs	_jc_jas_FieldCP$sub_refs;
typedef struct _jc_jas_FieldCP$sub_nonrefs	_jc_jas_FieldCP$sub_nonrefs;
typedef struct _jc_jas_FieldCP$refs	_jc_jas_FieldCP$refs;
typedef struct _jc_jas_FieldCP$nonrefs	_jc_jas_FieldCP$nonrefs;
typedef struct _jc_jas_FieldCP$object	_jc_jas_FieldCP$object;

typedef const struct _jc_jas_FieldCP$vmethods	_jc_jas_FieldCP$vmethods;
typedef const struct _jc_jas_FieldCP$vtable	_jc_jas_FieldCP$vtable;
typedef const struct _jc_jas_FieldCP$vtype	_jc_jas_FieldCP$vtype;

// Constructors
extern void _jc_jas_FieldCP$method$_init$ab068ddc672b930e(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_FieldCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_FieldCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_FieldCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_FieldCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_FieldCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_FieldCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_FieldCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_FieldCP$vmethods	jas_FieldCP;
};

// Vtype
struct _jc_jas_FieldCP$vtype {
	_jc_type			type;
	_jc_jas_FieldCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_FieldCP$sub_refs {
	struct _jc_jas_ClassCP$object	*clazz;
	struct _jc_jas_NameTypeCP$object	*nt;
};

// Reference instance fields (object)
struct _jc_jas_FieldCP$refs {
    _jc_jas_FieldCP$sub_refs	jas_FieldCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_FieldCP$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_jas_FieldCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_FieldCP$sub_nonrefs	jas_FieldCP;
};

// Object instance structure
struct _jc_jas_FieldCP$object {
	_jc_jas_FieldCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_FieldCP$vtype	*vtype;
	_jc_jas_FieldCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_FieldCP$vtype _jc_jas_FieldCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_FieldCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_FieldCP$class_object;

#endif	/* _JC_jas_FieldCP_H_ */
